<p align="center">
<img src="https://raw.githubusercontent.com/deanrp2/revarie/master/docs/logo/logo.png" height="120px">
</p>

[![Build Status](https://travis-ci.org/deanrp2/revarie.svg?branch=master)](https://travis-ci.org/deanrp2/revarie)
![Codecov](https://img.shields.io/codecov/c/github/deanrp2/revarie)
![GitHub](https://img.shields.io/github/license/deanrp2/revarie)
![PyPI](https://img.shields.io/pypi/v/revarie)
![GitHub top language](https://img.shields.io/github/languages/top/deanrp2/revarie)


# Overview
Revarie is intended to be a spatial statistical analysis toolset which is targeted for computational physics applications.
Its primary focus is on variography of cartesian fields. Currently, it supports computation and fitting of isotropic variograms along with other tools to support random field generation.

# Variogram Calculation

# Field Generation
